@@ -16,6 +16,7 @@ from yellowdog_client.model import (
     AutoShutdown,
     ComputeRequirementTemplateUsage,
     NodeWorkerTarget,
+    NodeWorkerTargetType,
     ProvisionedWorkerPoolProperties,
 )
 
@@ -46,7 +47,7 @@ from yellowdog_cli.utils.property_names import (
     WORKER_TAG,
 )
 from yellowdog_cli.utils.provision_utils import (
-    get_image_family_id,
+    get_image_id,
     get_template_id,
     get_user_data_property,
 )
@@ -169,13 +170,30 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
 
         # Allow Image Family name to be used instead of ID
         if reqt_template_usage.get(IMAGES_ID) is not None:
-            reqt_template_usage[IMAGES_ID] = get_image_family_id(
+            reqt_template_usage[IMAGES_ID] = get_image_id(
                 CLIENT, reqt_template_usage[IMAGES_ID]
             )
 
         # provisionedProperties insertions
         provisioned_properties = wp_data["provisionedProperties"]
 
+        # Three options for the number of workers per node
+        if CONFIG_WP.workers_custom_command is not None:
+            create_node_workers = {
+                "customTargetCommand": CONFIG_WP.workers_custom_command,
+                "targetType": "CUSTOM",
+            }
+        elif CONFIG_WP.workers_per_vcpu is not None:
+            create_node_workers = {
+                "targetCount": CONFIG_WP.workers_per_vcpu,
+                "targetType": "PER_VCPU",
+            }
+        else:  # Default option
+            create_node_workers = {
+                "targetCount": CONFIG_WP.workers_per_node,
+                "targetType": "PER_NODE",
+            }
+
         for key, value in [
             (WORKER_TAG, CONFIG_WP.worker_tag),
             (
@@ -208,20 +226,8 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
                     else {"enabled": False}
                 ),
             ),
-            (
-                "createNodeWorkers",
-                (
-                    {
-                        "targetCount": CONFIG_WP.workers_per_node,
-                        "targetType": "PER_NODE",
-                    }
-                    if CONFIG_WP.workers_per_vcpu is None
-                    else {
-                        "targetCount": CONFIG_WP.workers_per_vcpu,
-                        "targetType": "PER_VCPU",
-                    }
-                ),
-            ),
+            ("createNodeWorkers", create_node_workers),
+            ("metricsEnabled", CONFIG_WP.metrics_enabled),
         ]:
             if provisioned_properties.get(key) is None and value is not None:
                 print_log(f"Setting 'provisionedProperties.{key}': '{value}'")
@@ -283,8 +289,8 @@ def create_worker_pool_from_toml():
 
     # Allow the Image Family name to be used instead of ID
     if CONFIG_WP.images_id is not None:
-        CONFIG_WP.images_id = get_image_family_id(
-            client=CLIENT, image_family_id_or_name=CONFIG_WP.images_id
+        CONFIG_WP.images_id = get_image_id(
+            client=CLIENT, image_name_or_id=CONFIG_WP.images_id
         )
 
     node_boot_timeout = (
@@ -312,7 +318,11 @@ def create_worker_pool_from_toml():
     )
 
     # Establish the number of Workers to create
-    if CONFIG_WP.workers_per_vcpu is not None:
+    if CONFIG_WP.workers_custom_command is not None:
+        node_workers = NodeWorkerTarget.per_custom_command(
+            CONFIG_WP.workers_custom_command
+        )
+    elif CONFIG_WP.workers_per_vcpu is not None:
         node_workers = NodeWorkerTarget.per_vcpus(CONFIG_WP.workers_per_vcpu)
     else:
         node_workers = NodeWorkerTarget.per_node(CONFIG_WP.workers_per_node)
@@ -324,13 +334,21 @@ def create_worker_pool_from_toml():
         )
 
     # Create the Worker Pool
-    print_log(
-        f"Provisioning {CONFIG_WP.target_instance_count:,d} node(s) "
-        f"with {node_workers.targetCount} worker(s) "
-        f"{node_workers.targetType} "
-        f"(minNodes: {CONFIG_WP.min_nodes:,d}, "
-        f"maxNodes: {CONFIG_WP.max_nodes:,d})"
-    )
+    if node_workers.targetType == NodeWorkerTargetType.CUSTOM:
+        print_log(
+            f"Provisioning {CONFIG_WP.target_instance_count:,d} node(s) "
+            f"with a custom number of workers per node "
+            f"(minNodes: {CONFIG_WP.min_nodes:,d}, "
+            f"maxNodes: {CONFIG_WP.max_nodes:,d})"
+        )
+    else:
+        print_log(
+            f"Provisioning {CONFIG_WP.target_instance_count:,d} node(s) "
+            f"with {node_workers.targetCount} worker(s) "
+            f"{node_workers.targetType} "
+            f"(minNodes: {CONFIG_WP.min_nodes:,d}, "
+            f"maxNodes: {CONFIG_WP.max_nodes:,d})"
+        )
     batches: List[WPBatch] = _allocate_nodes_to_batches(
         CONFIG_WP.compute_requirement_batch_size,
         CONFIG_WP.target_instance_count,
@@ -382,6 +400,7 @@ def create_worker_pool_from_toml():
                 idleNodeShutdown=idle_node_auto_shutdown,
                 idlePoolShutdown=idle_pool_auto_shutdown,
                 nodeBootTimeout=node_boot_timeout,
+                metricsEnabled=CONFIG_WP.metrics_enabled,
             )
             if not ARGS_PARSER.dry_run:
                 worker_pool = CLIENT.worker_pool_client.provision_worker_pool(
@@ -425,6 +444,9 @@ def create_worker_pool_from_toml():
     )
     print_log(idle_pool_shutdown_msg)
 
+    if CONFIG_WP.metrics_enabled:
+        print_log("Node metrics are enabled")
+
     if ARGS_PARSER.dry_run:
         print_log("Dry-run: Complete")
         return
