@@ -16,11 +16,12 @@ from yellowdog_client.model import (
 from yellowdog_cli.utils.entity_utils import (
     get_worker_pool_by_id,
     get_worker_pool_id_by_name,
+    get_worker_pools,
 )
 from yellowdog_cli.utils.follow_utils import follow_ids
 from yellowdog_cli.utils.interactive import confirmed, select
 from yellowdog_cli.utils.misc_utils import link_entity
-from yellowdog_cli.utils.printing import print_error, print_log
+from yellowdog_cli.utils.printing import print_error, print_log, print_warning
 from yellowdog_cli.utils.wrapper import ARGS_PARSER, CLIENT, CONFIG_COMMON, main_wrapper
 from yellowdog_cli.utils.ydid_utils import YDIDType, get_ydid_type
 
@@ -37,9 +38,10 @@ def main():
         f"names including '{CONFIG_COMMON.name_tag}'"
     )
 
-    worker_pool_summaries: List[WorkerPoolSummary] = (
-        CLIENT.worker_pool_client.find_all_worker_pools()
+    worker_pool_summaries: List[WorkerPoolSummary] = get_worker_pools(
+        CLIENT, CONFIG_COMMON.namespace, CONFIG_COMMON.name_tag
     )
+
     shutdown_count = 0
 
     selected_worker_pool_summaries: List[WorkerPoolSummary] = []
@@ -73,7 +75,7 @@ def main():
                 print_log(f"Shut down {link_entity(CONFIG_COMMON.url, worker_pool)}")
                 optionally_terminate_compute_requirement(worker_pool_summary.id)
             except Exception as e:
-                print_error(f"Unable to shut down '{worker_pool_summary.name}': {e}")
+                print_error(f"Failed to shut down '{worker_pool_summary.name}': {e}")
 
     if shutdown_count > 0:
         print_log(f"Shut down {shutdown_count} Worker Pool(s)")
@@ -101,7 +103,7 @@ def shutdown_by_names_or_ids(names_or_ids: List[str]):
         else:
             worker_pool_id = get_worker_pool_id_by_name(CLIENT, name_or_id)
             if worker_pool_id is None:
-                print_error(f"Worker Pool '{name_or_id}' not found")
+                print_warning(f"Worker Pool '{name_or_id}' not found")
                 continue
         worker_pool_ids.append(worker_pool_id)
 
@@ -120,14 +122,14 @@ def shutdown_by_names_or_ids(names_or_ids: List[str]):
             print_log(f"Shut down Worker Pool '{worker_pool_id}'")
             optionally_terminate_compute_requirement(worker_pool_id)
         except Exception as e:
-            print_error(f"Unable to shut down Worker Pool '{worker_pool_id}': ({e})")
+            print_error(f"Failed to shut down Worker Pool '{worker_pool_id}': ({e})")
 
     for node_id in node_ids:
         try:
             CLIENT.worker_pool_client.shutdown_node_by_id(node_id)
             print_log(f"Shut down Node '{node_id}'")
         except Exception as e:
-            print_error(f"Unable to shut down Node '{node_id}': ({e})")
+            print_error(f"Failed to to shut down Node '{node_id}': ({e})")
 
     if ARGS_PARSER.follow:
         follow_ids(worker_pool_ids, auto_cr=ARGS_PARSER.auto_cr)
@@ -151,7 +153,7 @@ def optionally_terminate_compute_requirement(worker_pool_id: str):
             f"Terminated associated Compute Requirement '{worker_pool.computeRequirementId}'"
         )
     except Exception as e:
-        print_error(f"Error terminating Compute Requirement: ({e})")
+        print_error(f"Failed to terminate Compute Requirement: ({e})")
 
 
 # Entry point
